[![PyPI version](https://badge.fury.io/py/calibr8.svg)](https://badge.fury.io/py/calibr8)
[![pipeline](https://github.com/michaelosthege/calibr8/workflows/pipeline/badge.svg)](https://github.com/michaelosthege/calibr8/actions)
[![coverage](https://codecov.io/gh/michaelosthege/calibr8/branch/master/graph/badge.svg)](https://codecov.io/gh/michaelosthege/calibr8)
[![documentation](https://readthedocs.org/projects/calibr8/badge/?version=latest)](https://calibr8.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/306862348.svg)](https://zenodo.org/badge/latestdoi/306862348)


# `calibr8`
This package provides templates and functions for performing likelihood-based calibration modeling.
To see implementation examples & excercises, you can go to [notebooks/](notebooks).

# Installation
`calibr8` is released on [PyPI](https://pypi.org/project/calibr8/):

```
pip install calibr8
```
# Documentation
Read the package documentation [here](https://calibr8.readthedocs.io/en/latest/?badge=latest).

# Usage and Citing
`calibr8` is licensed under the [GNU Affero General Public License v3.0](https://github.com/michaelosthege/calibr8/blob/master/LICENSE).

Head over to Zenodo to [generate a BibTeX citation](https://doi.org/10.5281/zenodo.4127012) for the latest release.
